summaryrefslogtreecommitdiffstats
path: root/kplato/kpttask.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kpttask.cc')
-rw-r--r--kplato/kpttask.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/kplato/kpttask.cc b/kplato/kpttask.cc
index 964b8e4e..43ccb1bb 100644
--- a/kplato/kpttask.cc
+++ b/kplato/kpttask.cc
@@ -29,7 +29,7 @@
#include "kptschedule.h"
#include <tqdom.h>
-#include <tqbrush.h>
+#include <brush.h>
#include <kdebug.h>
namespace KPlato
@@ -198,7 +198,7 @@ bool Task::load(TQDomElement &element, Project &project) {
m_wbs = element.attribute("wbs", "");
// Load the project tqchildren
TQDomNodeList list = element.childNodes();
for (unsigned int i=0; i<list.count(); ++i) {
if (list.item(i).isElement()) {
@@ -570,7 +570,7 @@ void Task::initiateCalculationLists(TQPtrList<Node> &startnodes, TQPtrList<Node>
//kdDebug()<<k_funcinfo<<m_name<<endl;
if (type() == Node::Type_Summarytask) {
summarytasks.append(this);
// propagate my relations to my tqchildren and dependent nodes
TQPtrListIterator<Node> nodes = m_nodes;
for (; nodes.current(); ++nodes) {
@@ -1293,7 +1293,7 @@ void Task::clearProxyRelations() {
void Task::addParentProxyRelations(TQPtrList<Relation> &list) {
//kdDebug()<<k_funcinfo<<m_name<<endl;
if (type() == Type_Summarytask) {
// propagate to my tqchildren
//kdDebug()<<k_funcinfo<<m_name<<" is summary task"<<endl;
TQPtrListIterator<Node> nodes = m_nodes;
for (; nodes.current(); ++nodes) {
@@ -1315,7 +1315,7 @@ void Task::addParentProxyRelations(TQPtrList<Relation> &list) {
void Task::addChildProxyRelations(TQPtrList<Relation> &list) {
//kdDebug()<<k_funcinfo<<m_name<<endl;
if (type() == Type_Summarytask) {
// propagate to my tqchildren
//kdDebug()<<k_funcinfo<<m_name<<" is summary task"<<endl;
TQPtrListIterator<Node> nodes = m_nodes;
for (; nodes.current(); ++nodes) {
@@ -1337,7 +1337,7 @@ void Task::addChildProxyRelations(TQPtrList<Relation> &list) {
void Task::addParentProxyRelation(Node *node, const Relation *rel) {
if (node->type() != Type_Summarytask) {
if (type() == Type_Summarytask) {
- //kdDebug()<<"Add parent proxy from my tqchildren "<<m_name<<" to "<<node->name()<<endl;
+ //kdDebug()<<"Add parent proxy from my children "<<m_name<<" to "<<node->name()<<endl;
TQPtrListIterator<Node> nodes = m_nodes;
for (; nodes.current(); ++nodes) {
nodes.current()->addParentProxyRelation(node, rel);
@@ -1352,7 +1352,7 @@ void Task::addParentProxyRelation(Node *node, const Relation *rel) {
void Task::addChildProxyRelation(Node *node, const Relation *rel) {
if (node->type() != Type_Summarytask) {
if (type() == Type_Summarytask) {
- //kdDebug()<<"Add child proxy from my tqchildren "<<m_name<<" to "<<node->name()<<endl;
+ //kdDebug()<<"Add child proxy from my children "<<m_name<<" to "<<node->name()<<endl;
TQPtrListIterator<Node> nodes = m_nodes;
for (; nodes.current(); ++nodes) {
nodes.current()->addChildProxyRelation(node, rel);
@@ -1525,7 +1525,7 @@ bool Task::effortMetError() const {
}
#ifndef NDEBUG
-void Task::printDebug(bool tqchildren, TQCString indent) {
+void Task::printDebug(bool children, TQCString indent) {
kdDebug()<<indent<<"+ Task node: "<<name()<<" type="<<type()<<endl;
indent += "! ";
kdDebug()<<indent<<"Requested resources (total): "<<units()<<"%"<<endl;
@@ -1533,7 +1533,7 @@ void Task::printDebug(bool tqchildren, TQCString indent) {
if (m_requests)
m_requests->printDebug(indent);
- Node::printDebug(tqchildren, indent);
+ Node::printDebug(children, indent);
}
@@ -198,7 +198,7 @@ bool Task::load(TQDomElement &element, Project &project) {
m_wbs = element.attribute("wbs", "");
- // Load the project tqchildren
+ // Load the project children
TQDomNodeList list = element.childNodes();
for (unsigned int i=0; i<list.count(); ++i) {
@@ -570,7 +570,7 @@ void Task::initiateCalculationLists(TQPtrList<Node> &startnodes, TQPtrList<Node>
if (type() == Node::Type_Summarytask) {
summarytasks.append(this);
- // propagate my relations to my tqchildren and dependent nodes
+ // propagate my relations to my children and dependent nodes
TQPtrListIterator<Node> nodes = m_nodes;
for (; nodes.current(); ++nodes) {
@@ -1293,7 +1293,7 @@ void Task::clearProxyRelations() {
//kdDebug()<<k_funcinfo<<m_name<<endl;
if (type() == Type_Summarytask) {
- // propagate to my tqchildren
+ // propagate to my children
//kdDebug()<<k_funcinfo<<m_name<<" is summary task"<<endl;
TQPtrListIterator<Node> nodes = m_nodes;
@@ -1315,7 +1315,7 @@ void Task::addParentProxyRelations(TQPtrList<Relation> &list) {
//kdDebug()<<k_funcinfo<<m_name<<endl;
if (type() == Type_Summarytask) {
- // propagate to my tqchildren
+ // propagate to my children
//kdDebug()<<k_funcinfo<<m_name<<" is summary task"<<endl;
TQPtrListIterator<Node> nodes = m_nodes;